/*
** Module   : LegacyAttribute.java
** Abstract : Annptation used to declare legacy Progress attribute.
**
** Copyright (c) 2013, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- ---------------------------------Description----------------------------------
** 001 EVL 20130910 Created initial version.
** 002 EVL 20131014 Added ignore() member to handle static methods defining attributes that really
**                  should be ignored for the given class.
*/

package com.goldencode.p2j.util;

import java.lang.annotation.*;

/**
 * Annotation definition to mark methods as the replacements for Progress 4GL attributes. This
 * annotation stores the legacy attribute name and a flag to note if this is a getter
 * or setter.
 */
@Target(ElementType.METHOD)
@Retention(RetentionPolicy.RUNTIME)
public @interface LegacyAttribute
{
   /** The name of the legacy attribute marked with this annotation. */
   String name();
   
   /** The member identifying if the legacy attribute has the setter or getter only. */
   boolean setter() default false;
   
   /** The member identifying if the legacy attribute to be ignored for the given method. */
   boolean ignore() default false;
}

